import axios from 'axios'
import {Message} from 'element-ui'
import {
	getToken,
	setToken
} from './auth.js'
import qs from 'qs'

const service = axios.create({
	baseURL: process.env.VUE_APP_BASE_API, // api的base_url
	timeout: 5000,
	headers: {
		'Content-Type': 'application/x-www-form-urlencoded'
	},
	transformRequest: [function(data) {
		return qs.stringify(data)
	}]
})

service.interceptors.request.use(
	config => {
		if (getToken()) {
			config.headers['A-Token'] = getToken()
			// config.headers['A-Token'] = ' eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.eyJpc3MiOiJodHRwczpcL1wvZGluZy5pbnN5cy5nMTA3LmNvbVwvYXBpXC9kaW5nXC9sb2dpbiIsImlhdCI6MTYwMDY3NjM5NCwiZXhwIjoxNjAxMjc2Mzk0LCJuYmYiOjE2MDA2NzYzOTQsImp0aSI6IkpPZWZoc0ZpWlpLeUFubHgiLCJzdWIiOjIsInBydiI6ImNhNjQ4OWQ1MGYyNDA3YTY3ODMwZTgwOTBkMDE0ODgzNTY4NTk2MmIiLCJyb2xlIjoiZW1wbG95ZWUifQ.n4UbsnWf48m9tyb7yCHmvkULu-WK2sdrBc8lC2tQxKc'
		}
		return config
	},
	error => {
		Promise.reject(error)
	}
)

// respone interceptor
service.interceptors.response.use(
	response => {
		if (response.data.code === 1) {
			if(response.data.data.token){
				setToken(response.data.data.token);
			}else if (response.data.refresh_token) {
				if (response.data.refresh_token !== getToken()) {
					setToken(response.data.refresh_token);
				}
			}
			return response;
		} else if (response.data.code === 401) {
			Message({
				message: response.data.msg,
				type: 'error',
			})
			return Promise.reject(response.data.msg)
		}else{
			Message({
				message: response.data.msg,
				type: 'error',
			})
			return Promise.reject(response.data.msg)
		}
	},
	error => {
		if(error.message=='interrupt'){
			// Message({
			// 	message: '请勿频繁切换页面',
			// 	type: 'warning',
			// })
			return Promise.reject(error.message)
		}
		Message({
			message: error.message,
			type: 'error',
		})
		return Promise.reject(error.message)
	}
)

export default service
